Page 57 of The Secret Side Of History Mystery Babylon, 209P | thedailydialectics
Description: Document: The Secret Side Of History Mystery Babylon, 209P
Keywords: The Secret Side Of History Mystery Babylon, 209P

# The Secret Side Of History Mystery Babylon, 209P — Page 57

Home

    love was to replace marriage, friendships were to be
    forced upon people by law, children were to become
    property of the State, with the State dictating how they
    should be raised. No area of life was to escape the

    watchful eye of big brother.
    What had all of this done to the people of France?
    Not only had it destroyed their industries, their

    their

    their

    culture,

    and

    their

    families,

    its

    destruction had also reached into the very soul of France.
    A personal observation of this was told by the British
    historian John Robison:

    A most worthy and accomplished gentleman, who
    took refuge in this country, leaving behind him his
    property, and friends to whom he was most tenderly
    attached, often said to me that nothing so much affected
    him as the revolution in the hearts of men. — Characters
    which were unspotted, hearts thoroughly known to
    himself, having been tried by many things which search
    the inmost folds of selfishness or malevolence — in short,
    persons whose judgements were excellent, and on whose
    worth he could have rested his honor and his life, so
    fascinated by the contagion, that they came at last to
    behold, and even to commit the most atrocious crimes
    with delight.'°

    And what of the men who planned and carried out the
    Revolution? Almost to a man they perished as a result of
    the terror they had created for others. Procession after
    procession made its way to the guillotine as the factions
    and leaders turned on and destroyed each other. The lust

    52

    The Secret Side of History

    Not only had it destroyed

    commerce,